@@ -15,18 +15,6 @@ var Unity = external.getUnityObject(1);
 window.Unity = Unity;
 unsafeWindow.Unity = window.Unity;
 
-function isCorrectPage() {
-    var i, ids = ['page', 'footer-container'];
-
-    for (i = 0; i < ids.length; i++) {
-        if (!document.getElementById(ids[i])) {
-            return false;
-        }
-    }
-
-    return true;
-}
-
 function getParams() {
     var query = window.location.search;
     var match, search = /([^&=]+)=?([^&]*)/g;
@@ -72,21 +60,16 @@ function musicPlayerSetup() {
         });
     }
 
-    var titleLabel = document.getElementById("eow-title");
+    var titleLabel = document.evaluate('//h1[@id="watch-headline-title"]/span',
+                                       document,
+                                       null,
+                                       XPathResult.ANY_UNORDERED_NODE_TYPE,
+                                       null).singleNodeValue;
     var artLocation = null;
     try {
-        artLocation = document.evaluate('//*[@class="playlist-bar-item yt-uix-slider-slide-unit playlist-bar-item-playing"]/a/span/span/span/img',
-                                      document,
-                                      null,
-                                      XPathResult.ANY_UNORDERED_NODE_TYPE,
-                                      null).singleNodeValue.src;
-    } catch (e) {}
-    try {
-        if (!artLocation && titleLabel) {
-            var id = getParams()['v'];
-            if (id) {
-                artLocation = 'http://i3.ytimg.com/vi/' + id + '/default.jpg';
-            }
+        var id = getParams()['v'];
+        if (id) {
+            artLocation = 'http://i3.ytimg.com/vi/' + id + '/default.jpg';
         }
     } catch (e) {}
     var trackInfo = {
@@ -116,10 +99,10 @@ function musicPlayerSetup() {
                 isPlaying = !isPlaying;
             }
         } else { //html5 player
-            var button = document.evaluate('//div[@id="movie_player-html5"]/div[3]/div[2]/button', document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue;
-            isPlaying = !String(button.className).match(/html5-pause-button/);
+            var button = document.evaluate('//div[@id="movie_player-html5"]/div[3]/div/button[contains(@class, "html5-control")]', document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue;
+            isPlaying = String(button.className).match(/html5-pause-button/);
             if (!dryRun) {
-                launchClickEvent(button);
+                button.click();
                 isPlaying = !isPlaying;
             }
         }
@@ -147,10 +130,8 @@ function musicPlayerSetup() {
     evalInPageContext('function() {setInterval(function() {(' + String(changeState) + ')(true)}, 1000);}');
 }
 
-if (isCorrectPage()) {
-    Unity.init({ name: "YouTube",
-		 domain: 'youtube.com',
-		 homepage: 'http://www.youtube.com',
-                 iconUrl: "icon://unity-webapps-youtube",
-                 onInit: musicPlayerSetup });
-}
+Unity.init({ name: "YouTube",
+	     domain: 'youtube.com',
+	     homepage: 'http://www.youtube.com',
+             iconUrl: "icon://unity-webapps-youtube",
+             onInit: musicPlayerSetup });
